# file generated by setuptools_scm
# don't change, don't track in version control
__version__ = version = '0.0.8.dev0+g1f54196.d20230205'
__version_tuple__ = version_tuple = (0, 0, 8, 'dev0', 'g1f54196.d20230205')
